"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert = require("assert");
const packages_1 = require("../packages");
describe('packages.ts', () => {
    describe('extractDefinitelyTypedPackageName()', () => {
        it('should return the @types package name for a file in DefinitelyTyped', () => {
            const packageName = packages_1.extractDefinitelyTypedPackageName('file:///types/node/index.d.ts');
            assert.equal(packageName, '@types/node');
        });
        it('should return undefined otherwise', () => {
            const packageName = packages_1.extractDefinitelyTypedPackageName('file:///package.json');
            assert.strictEqual(packageName, undefined);
        });
    });
    describe('extractNodeModulesPackageName()', () => {
        it('should return the package name for a file in node_modules', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/node_modules/bar/baz/test.ts');
            assert.equal(packageName, 'bar');
        });
        it('should return the package name for a file in a scoped package in node_modules', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/node_modules/@types/bar/baz/test.ts');
            assert.equal(packageName, '@types/bar');
        });
        it('should return the package name for a file in nested node_modules', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/node_modules/bar/node_modules/baz/test.ts');
            assert.equal(packageName, 'baz');
        });
        it('should return undefined otherwise', () => {
            const packageName = packages_1.extractNodeModulesPackageName('file:///foo/bar');
            assert.strictEqual(packageName, undefined);
        });
    });
});
//# sourceMappingURL=package.test.js.map