import * as ts from 'typescript';
import { SymbolKind } from 'vscode-languageserver';
import { SymbolDescriptor } from './request-type';
/**
 * Toggles "strict" flag, affects how we are parsing/generating URLs.
 * In strict mode we using "file://PATH", otherwise on Windows we are using "file:///PATH"
 */
export declare function setStrict(value: boolean): void;
/**
 * Makes documentation string from symbol display part array returned by TS
 */
export declare function docstring(parts: ts.SymbolDisplayPart[]): string;
/**
 * Normalizes path to match POSIX standard (slashes)
 */
export declare function toUnixPath(filePath: string): string;
export declare function convertStringtoSymbolKind(kind: string): SymbolKind;
/**
 * Normalizes URI encoding by encoding _all_ special characters in the pathname
 */
export declare function normalizeUri(uri: string): string;
export declare function path2uri(root: string, file: string): string;
export declare function uri2path(uri: string): string;
export declare function uriToLocalPath(uri: string): string;
export declare function isLocalUri(uri: string): boolean;
export declare function resolve(root: string, file: string): string;
export declare function isJSTSFile(filename: string): boolean;
export declare function isConfigFile(filename: string): boolean;
export declare function isPackageJsonFile(filename: string): boolean;
export declare function isGlobalTSFile(filename: string): boolean;
export declare function isDependencyFile(filename: string): boolean;
export declare function isDeclarationFile(filename: string): boolean;
/**
 * Converts filename to POSIX-style absolute one if filename does not denote absolute path already
 */
export declare function absolutize(filename: string): string;
/**
 * Absolutizes directory name and cuts trailing slashes
 */
export declare function normalizeDir(dir: string): string;
/**
 * defInfoToSymbolDescriptor converts from an instance of
 * ts.DefinitionInfo to an instance of SymbolDescriptor
 */
export declare function defInfoToSymbolDescriptor(d: ts.DefinitionInfo): SymbolDescriptor;
/**
 * Returns true if the passed SymbolDescriptor has at least the same properties as the passed partial SymbolDescriptor
 */
export declare function isSymbolDescriptorMatch(query: Partial<SymbolDescriptor>, symbol: SymbolDescriptor): boolean;
